# devind_yearfrac

[![CI](https://github.com/devind-team/devind_yearfrac/workflows/Release/badge.svg)](https://github.com/devind-team/devind_yearfrac/actions)
[![PyPI version](https://badge.fury.io/py/devind_yearfrac.svg)](https://badge.fury.io/py/devind_yearfrac)
[![License: MIT](https://img.shields.io/badge/License-MIT-success.svg)](https://opensource.org/licenses/MIT)

This is a fork of [`yearfrac`](https://github.com/kmedian/yearfrac) for use in
[`xlsx_evaluate`](https://github.com/devind-team/xlsx_evaluate).
This fork mainly supports `poetry` and newer versions of Python.

## Installation
```
poetry add devind_yearfrac
```
